
package sub_arctic.input;

/** 
 * Input protocol interface for objects that wish to "track" (that is see,
 * but not consume) all mouse press and release events.  This can be used, for
 * example to rest set of releases that one would normally not see.  This
 * protocol is dispatched by the click_track_agent.
 *
 * @see sub_arctic.input.click_track_agent
 * @author Scott Hudson
 */
public interface click_tracking extends focusable {

  /** 
   * Dispatch press and release events to the object so it can track 
   * mouse button state outside its normal domain.
   * 
   * @param event evt the press or release event.
   * @param Object the uninterpreted user information that was provided when 
   *               the object established itself as a focus for this type 
   *               of input.
   * @return boolean whether the event was consumed (in this case this is 
   *                 ignored).
   */
  public boolean track_click(event evt, Object user_info);
}
/*=========================== COPYRIGHT NOTICE ===========================

This file is part of the subArctic user interface toolkit.

Copyright (c) 1996 Scott Hudson and Ian Smith
All rights reserved.

The subArctic system is freely available for most uses under the terms
and conditions described in 
  http://www.cc.gatech.edu/gvu/ui/sub_arctic/sub_arctic/doc/usage.html 
and appearing in full in the lib/interactor.java source file.

The current release and additional information about this software can be 
found starting at: http://www.cc.gatech.edu/gvu/ui/sub_arctic/

========================================================================*/
