package sub_arctic.input;

/**
 * This input protocol is used to display help messages on the screen
 * when an object has the mouse over it for some period of time.
 * If you are considering implementing this interface, you should
 * probably be sure to examine the display_help_container class
 * in the lib package.<p>
 *
 * <STRONG>Warning</STRONG>: This protocol is based on the various mouse
 * events that are dispatched by the system. If you modify an interface
 * based on other types of events (e.g. animation), the display_help
 * interface's help_close() call will not be made immediately. In particular,
 * such a call will not be made until the next mouse event is processed.
 *
 * @author Ian Smith
 */
public interface display_help extends pointable {
  /**
   * This method is called to inform the object that the help text
   * should be displayed now. This not called in response
   * to an event, nor is there a way to claim that this is successfully
   * dispatched, since no event is being processed. In particular,
   * this method only gets called when the system is <STRONG>not</STRONG>
   * not receiving mouse input (i.e. the user is not moving
   * the mouse).
   */
  public void help_open(); //xx this *MUST* have an event and user_info added

  /**
   * This method is called to inform the object that the help text
   * should not be displayed any longer. Although this method is
   * called in response to a user input, the display_help container
   * cannot "dispatch" this event in the normal sense, since it
   * is likely that other agents may have handled this event.
   */
  public void help_close(event evt); //xx need user_info
}
/*=========================== COPYRIGHT NOTICE ===========================

This file is part of the subArctic user interface toolkit.

Copyright (c) 1996 Scott Hudson and Ian Smith
All rights reserved.

The subArctic system is freely available for most uses under the terms
and conditions described in 
  http://www.cc.gatech.edu/gvu/ui/sub_arctic/sub_arctic/doc/usage.html 
and appearing in full in the lib/interactor.java source file.

The current release and additional information about this software can be 
found starting at: http://www.cc.gatech.edu/gvu/ui/sub_arctic/

========================================================================*/
