
package sub_arctic.constraints;

/**
 * Interface for objects that represent constraints.  A constraint 
 * consists of an encoding (an integer) and a reference to constraint_impl 
 * object that nows how to interpret that encoding (or provides the full 
 * contents of the constraint itself).  Finally, it also provides a few 
 * methods for querying the properties of the constraint.
 *
 * @author Scott Hudson
 */
public interface constraint {
  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** 
   * Encoding of constraint as an integer.<p> 
   *
   * @see constraints.std_encoding_consts
   * @return int the encoding value for the constraint
   */ 
  public int encoding();

  /** 
   * The implementation object for this constraint. 
   * 
   * @see constraints.std_constraint_impl
   * @return constraint_impl the implementation object for this constraint.
   * */
  public constraint_impl impl();

  /** 
   * Orientation of the constraint.  This is a bitset made up of any of:
   * std_encoding_consts.HORIZONTAL, std_encoding_consts.VERTICAL, and/or
   * std_encoding_consts.NOT_ORIENTED.
   *
   * @see constraints.std_encoding_consts
   * @return int the bitset for the orientation(s) of this constraint
   */
  public int orientation();

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** 
   * Indicate if this constraint is actually encoding for no constraint. 
   * @return boolean true if this constraint represents no constraint.
   */
  public boolean is_none();

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** 
   * Indicate if this constraint is encoding for an external constraint. 
   * @return boolean true if this constraint is an external (AKA heavyweight)
   *                      constraint
   */
  public boolean is_external();

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** Convert to a human readable string */
  public String toString();

  /** Convert to a terse human readable string */
  public String tag();

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */
}
/*=========================== COPYRIGHT NOTICE ===========================

This file is part of the subArctic user interface toolkit.

Copyright (c) 1996 Scott Hudson and Ian Smith
All rights reserved.

The subArctic system is freely available for most uses under the terms
and conditions described in 
  http://www.cc.gatech.edu/gvu/ui/sub_arctic/sub_arctic/doc/usage.html 
and appearing in full in the lib/interactor.java source file.

The current release and additional information about this software can be 
found starting at: http://www.cc.gatech.edu/gvu/ui/sub_arctic/

========================================================================*/
