
package sub_arctic.constraints;

/**
 * Interface to define user accessible constraint encoding constants.<p>
 * This interface defines a series of "constant factories" used to designate
 * parts of objects in a standard constraint.  These are used in conjunction 
 * with the methods in std_function to define constraints from the standard 
 * set.<p>
 *
 * @author Scott Hudson
 */

public interface std_constraint_consts {

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of the parent object.  This provides
   *  a set of "constants" designating objects parts (e.g., SELF.X()). */
  public static final std_objpart_encoding SELF 
      = new std_objpart_encoding(std_encoding_consts.OBJCODE_SELF, 0, 0); 

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of the parent object.  This provides
   *  a set of "constants" designating objects parts (e.g., PARENT.X()). */
  public static final std_objpart_encoding PARENT 
      = new std_objpart_encoding(std_encoding_consts.OBJCODE_PARENT, 0, 0); 

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of the first child object.  This 
   *  provides a set of "constants" designating objects parts (e.g., 
   *  FIRST_CHILD.X()).*/
  public static final std_objpart_encoding FIRST_CHILD 
      = new std_objpart_encoding(std_encoding_consts.OBJCODE_FIRST_CHILD, 0, 0);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of the last child object.  This 
   *  provides a set of "constants" designating objects parts (e.g., 
   *  LAST_CHILD.X()).*/
  public static final std_objpart_encoding LAST_CHILD 
      = new std_objpart_encoding(std_encoding_consts.OBJCODE_LAST_CHILD, 0, 0); 

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of the max child object.  This 
   *  provides a set of "constants" designating objects parts (e.g., 
   *  MAX_CHILD.X()).*/
  public static final std_objpart_encoding MAX_CHILD 
      = new std_objpart_encoding(std_encoding_consts.OBJCODE_MAX_CHILD, 0, 0);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of the min child object.  This 
   *  provides a set of "constants" designating objects parts (e.g., 
   *  MIN_CHILD.X()).*/
  public static final std_objpart_encoding MIN_CHILD 
      = new std_objpart_encoding(std_encoding_consts.OBJCODE_MIN_CHILD, 0, 0);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of the previous sibling object.  
   *  This provides a set of "constants" designating objects parts (e.g., 
   *  PREV_SIBLING.X()).*/
  public static final std_objpart_encoding PREV_SIBLING 
     = new std_objpart_encoding(std_encoding_consts.OBJCODE_PREV_SIBLING, 0, 0);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of the next sibling object.  This 
   *  provides a set of "constants" designating objects parts (e.g., 
   *  NEXT_SIBLING.X()).*/
  public static final std_objpart_encoding NEXT_SIBLING 
     = new std_objpart_encoding(std_encoding_consts.OBJCODE_NEXT_SIBLING, 0, 0);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** "Constant factory" object for parts of a non-local object.  This provides
   *  as set of "constants" designating standard or non-standard object parts 
   *  (e.g., OTHER.OBJ(some_obj).PART(some_part) or OTHER.OBJ(some_obj).X()).*/
  public static final ext_maker OTHER = new ext_maker(); 

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** Part designator constant for specifying a zero value. PARENT.x() always
   *  returns 0, so this actually expands to a non-oriented version of that. 
   */
  public static final std_objpart_encoding ZERO = new std_objpart_encoding(
    std_encoding_consts.OBJCODE_PARENT, std_encoding_consts.PARTCODE_XY, 
    std_encoding_consts.NOT_ORIENTED);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** Encoding for no constraint.  We need this since we always store some 
   *  encoding for the attribute. */
  public static final std_constraint NO_CONSTRAINT = new std_constraint(
    (std_encoding_consts.OP_NONE << std_encoding_consts.OP0_SHIFT) | 
     std_encoding_consts.OP0_LOBITS, 0);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */
}

/*=========================== COPYRIGHT NOTICE ===========================

This file is part of the subArctic user interface toolkit.

Copyright (c) 1996 Scott Hudson and Ian Smith
All rights reserved.

The subArctic system is freely available for most uses under the terms
and conditions described in 
  http://www.cc.gatech.edu/gvu/ui/sub_arctic/sub_arctic/doc/usage.html 
and appearing in full in the lib/interactor.java source file.

The current release and additional information about this software can be 
found starting at: http://www.cc.gatech.edu/gvu/ui/sub_arctic/

========================================================================*/
