
package sub_arctic.input;

import sub_arctic.lib.interactor;

/** 
 * Interface for objects that receive callback from interactors.  All callbacks
 * are made through this API.
 *
 * @author Scott Hudson
 */
public interface callback_object {
  /** 
   * The following method is invoked for each callback resulting from actions
   * performed on an interactor object.  It gives the interactor making the 
   * call, the event "causing" the callback, an integer indicating 
   * which kind of callback is being made (for interactors that support 
   * multiple callbacks), a generic object that provides parameters to the 
   * the callback.
   *
   * @param interactor from_obj      the interactor making the callback.
   * @param event      evt           the event which "caused" the callback.
   * @param int        callback_num  which callback type this is.
   * @param Object     callback_info additional information about this callback
   *                                 (the exact type of this information is 
   *                                 determined by the callback type).
   */  
  void callback(
    interactor from_obj, 
    event      evt,
    int        callback_num, 
    Object     callback_info);
}
/*=========================== COPYRIGHT NOTICE ===========================

This file is part of the subArctic user interface toolkit.

Copyright (c) 1996 Scott Hudson and Ian Smith
All rights reserved.

The subArctic system is freely available for most uses under the terms
and conditions described in 
  http://www.cc.gatech.edu/gvu/ui/sub_arctic/sub_arctic/doc/usage.html 
and appearing in full in the lib/interactor.java source file.

The current release and additional information about this software can be 
found starting at: http://www.cc.gatech.edu/gvu/ui/sub_arctic/

========================================================================*/
