package sub_arctic.input;

/** 
 * Input protocol for objects receiving input from the move_press_drag agent.
 * This agent is a hybrid positional-focus.  It responds to press events
 * over an object, by making that object the move_drag focus.  The actual
 * input protocol is the same as move_drag (i.e., the object never gets or 
 * handles, the press, only the drag). <p>
 * 
 * Note: this does not add any methods to move_draggable.  It exists only so
 * we can differentiate objects that want us to handle the press for them from
 * plain move_draggable objects.<p>
 *
 * @see sub_arctic.input.pressable
 * @see sub_arctic.input.move_draggable
 * @see sub_arctic.input.move_press_drag_agent
 *
 * @author Scott Hudson
 */
public interface move_press_draggable extends move_draggable {

  /* No extra methods over move_draggable -- we just need to mark objects 
   * using this via the move_press_draggable interface name.
   */
}
/*=========================== COPYRIGHT NOTICE ===========================

This file is part of the subArctic user interface toolkit.

Copyright (c) 1996 Scott Hudson and Ian Smith
All rights reserved.

The subArctic system is freely available for most uses under the terms
and conditions described in 
  http://www.cc.gatech.edu/gvu/ui/sub_arctic/sub_arctic/doc/usage.html 
and appearing in full in the lib/interactor.java source file.

The current release and additional information about this software can be 
found starting at: http://www.cc.gatech.edu/gvu/ui/sub_arctic/

========================================================================*/
