
package sub_arctic.input;

/** 
 * Input protocol interface for objects which wish to receive single mouse
 * button down (press) and up (release) events.  This input protocol is 
 * managed by the click_agent.  See click_agent for a discussion of the 
 * interaction between this protocol, click, and double-click.
 *
 * @see sub_arctic.input.click_agent
 * @author Scott Hudson
 */
public interface pressable {

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /** 
   * Dispatch mouse button press input to the object.  
   * 
   * @param event  evt       the event for the press.
   * @param Object user_info the user information that was associated with 
   *                         the pick used to dispatch this input to this 
   *                         object.
   * @return boolean indicating if the event was consumed.
   */
  public boolean press(event evt, Object user_info);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */

  /**
   * Dispatch mouse button release input to the object.  
   * 
   * @param event  evt       the event for the release.
   * @param Object user_info the user information that was associated with 
   *                         the pick used to dispatch this input to this 
   *                         object.
   * @return boolean indicating if the event was consumed.
   */
  public boolean release(event evt, Object user_info);

  /* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . */
}
/*=========================== COPYRIGHT NOTICE ===========================

This file is part of the subArctic user interface toolkit.

Copyright (c) 1996 Scott Hudson and Ian Smith
All rights reserved.

The subArctic system is freely available for most uses under the terms
and conditions described in 
  http://www.cc.gatech.edu/gvu/ui/sub_arctic/sub_arctic/doc/usage.html 
and appearing in full in the lib/interactor.java source file.

The current release and additional information about this software can be 
found starting at: http://www.cc.gatech.edu/gvu/ui/sub_arctic/

========================================================================*/
