
package sub_arctic.test;

import sub_arctic.lib.base_interactor;
import sub_arctic.lib.manager;
import sub_arctic.output.drawable;
import java.awt.Color;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Point;

/** Demo class which displays its own size within a solid rectangle */
public class size_tracker extends base_interactor {

  /** Text of the coordinate */
  protected String      _coord_str = "";

  /** Font to display in */
  protected Font        _drawing_font;

  /** Cached metrics of the font */
  protected FontMetrics _metric;

  /** Full constructor */
  public size_tracker(int xv, int yv, Font in_fnt)
    {
      super(xv,yv);

      /* set tag with dummy value for now */
      _coord_str = "?x?";

      /* use a default font if none was given */
      if (in_fnt == null) in_fnt = new Font("Helvetica", Font.PLAIN, 24);

      /* establish a font and cache metrics object */
      _drawing_font = in_fnt;
      _metric = manager.get_metrics(_drawing_font);

      /* force object to be reconfigured and redrawn */
      damage_self();
    }

  /** Constructor with default font */
  public size_tracker(int xv, int yv)
    {
      this(xv,yv,null);
    }

  /** Constructor with all defaults */
  public size_tracker()
    {
      this(0,0,null);
    }

  /** Recompute object's display string based on its size */
  public void configure()
    {
      _coord_str = Integer.toString(w()) + "x" + Integer.toString(h());
      super.configure();
    }

  /** Provide drawing behavior for the object */
  protected void draw_self_local(drawable d)
    {
      d.setColor(Color.blue);
      d.fillRect(0,0,w(),h());
      d.setColor(Color.white);
      d.setFont(_drawing_font);
      d.drawString(_coord_str, 2, _metric.getAscent()+2);
      d.setColor(Color.black);
    }
};
/*=========================== COPYRIGHT NOTICE ===========================

This file is part of the subArctic user interface toolkit.

Copyright (c) 1996 Scott Hudson and Ian Smith
All rights reserved.

The subArctic system is freely available for most uses under the terms
and conditions described in 
  http://www.cc.gatech.edu/gvu/ui/sub_arctic/sub_arctic/doc/usage.html 
and appearing in full in the lib/interactor.java source file.

The current release and additional information about this software can be 
found starting at: http://www.cc.gatech.edu/gvu/ui/sub_arctic/

========================================================================*/
